@@ -483,6 +483,10 @@ class VertexAIWorker(BaseWorker):
         )
         scheduling = Scheduling(timeout=timeout)
 
+        if "service_account_name" in configuration.job_spec:
+            service_account_name = configuration.job_spec.pop("service_account_name")
+            configuration.job_spec["service_account"] = service_account_name
+
         # construct the final job spec that we will provide to Vertex AI
         job_spec = CustomJobSpec(
             worker_pool_specs=worker_pool_specs,
